# NaoTH Python Package
This package contains various scripts for working with naoth logs.

## datasets sub package
TODO: add explanation

## log sub package
TODO: add explanation

## math
TODO: add explanation

## pb
TODO: add explanation

## utils
TODO: add explanation

## other
TODO: add explanation
